/**
	$Id: ServletWrapperKey.java 5606 2011-04-14 07:45:23Z nicklas $

	Copyright (C) 2011 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.clients.web.extensions;

import net.sf.basedb.util.extensions.manager.ObjectKey;

/**
	Key implementation used to identify servlets. 
	We need both the file name and the servlet name
	to be able to do this.
	
	@author Nicklas
	@since 3.0
	@base.modified $Date: 2011-04-14 09:45:23 +0200 (Thu, 14 Apr 2011) $
*/
public class ServletWrapperKey 
	implements ObjectKey<ServletWrapper> 
{

	private final String jarFile;
	private final String servletName;
	
	/**
		Create a new key for a servlet defined in a file with the
		given name.
		@param jarFile The name of the JAR file in which the servlet was defined
		@param servletName The name of the servlet
	*/
	public ServletWrapperKey(String jarFile, String servletName)
	{
		this.jarFile = jarFile;
		this.servletName = servletName;
	}
	
	/*
		From the ObjectKey interface
		----------------------------
	*/
	@Override
	public String toDescription()
	{
		return "Servlet '" + servletName + "'";
	}
	// -----------------------------

	
	/*
		From the Object class
		---------------------
	*/
	@Override
	public int hashCode()
	{
		return jarFile.hashCode() + servletName.hashCode();
	}
	
	@Override
	public boolean equals(Object obj)
	{
		if (this == obj) return true;
		if (obj == null || obj.getClass() != this.getClass()) return false;
		ServletWrapperKey other = (ServletWrapperKey)obj;
		return other.jarFile.equals(this.jarFile) && other.servletName.equals(other.servletName);
	}
	
	@Override
	public String toString()
	{
		return "ServletWrapperKey@" + System.identityHashCode(this) + "[" + jarFile + ":" + servletName +"]";
	}
	// -----------------------

	
}
