package net.sf.basedb.clients.web.extensions.fileviewer;

import net.sf.basedb.clients.web.extensions.AbstractJspActionFactory;
import net.sf.basedb.clients.web.extensions.JspContext;
import net.sf.basedb.clients.web.extensions.fileviewer.FileViewerContext.Type;
import net.sf.basedb.clients.web.extensions.toolbar.ButtonAction;
import net.sf.basedb.clients.web.extensions.toolbar.ButtonBean;
import net.sf.basedb.core.File;
import net.sf.basedb.core.Location;
import net.sf.basedb.util.Values;
import net.sf.basedb.util.extensions.InvokationContext;

/**
	Facotry for creating the "View" and "Download" actions in file lists.
	@author nicklas
	@since 3.16
*/
public class ViewAndDownloadActionFactory 
	extends AbstractJspActionFactory<ButtonAction>
{

	public ViewAndDownloadActionFactory() 
	{}
	
	@Override
	public ButtonAction[] getActions(InvokationContext<? super ButtonAction> context) 
	{
		JspContext jspContext = (JspContext)context.getClientContext();
		FileViewerContext fctx = (FileViewerContext)jspContext.getCurrentItem();
		File f = fctx.getFile();
		if (f == null) return null;
		ButtonAction[] actions = null;
		
		Location l = f.getLocation();
		if (l == Location.OFFLINE)
		{
			if (fctx.getType() == Type.FILE)
			{
				// Here we add an "Upload" action
				ButtonBean upload = new ButtonBean();
				upload.setVisible(true);
				upload.setClazz("link auto-init");
				upload.setIcon(jspContext.getRoot()+"/images/upload.png");
				upload.setTitle("Upload this file again");
				upload.setDynamicAttribute("data-file-id", f.getId());
				upload.setDynamicAttribute("data-auto-init", "upload-file");
				actions = new ButtonAction[] { upload };
			}
			else
			{
				ButtonBean offline = new ButtonBean();
				offline.setVisible(true);
				offline.setIcon(jspContext.getRoot()+"/images/offline.png");
				offline.setTitle("This file is offline");
				actions = new ButtonAction[] { offline };
			}
		}
		else if (l.isDownloadable())
		{
			String bytes = Values.formatBytes(f.getSize(), 1);
			
			ButtonBean view = new ButtonBean();
			view.setVisible(true);
			view.setClazz("link auto-init");
			view.setTitle("View the contents of this file (" + bytes + ")");
			view.setIcon(jspContext.getRoot()+"/images/view.png");
			view.setDynamicAttribute("data-file-id", f.getId());
			view.setDynamicAttribute("data-auto-init", "view-file");
			
			ButtonBean download = new ButtonBean();
			download.setVisible(true);
			download.setClazz("link auto-init");
			download.setTitle("Download the contents of this file (" + bytes + ")");
			download.setIcon(jspContext.getRoot()+"/images/download.png");
			download.setDynamicAttribute("data-file-id", f.getId());
			download.setDynamicAttribute("data-auto-init", "download-file");
			
			actions = new ButtonAction[] { view, download };
		}
		return actions;
	}

}
