/*
	$Id: ColumnHeaders.java 6898 2015-05-12 09:27:08Z nicklas $

	Copyright (C) 2011 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.clients.web.taglib.table;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.JspTagException;

import net.sf.basedb.clients.web.taglib.StylableTag;

/**
	Generate column subtitle header for the columns that has been defined for 
	this table. This tag has no attributes, except standard id, class and style,
	and should be last tag inside
	&lt;headers&gt;

	<p>
	<b>Syntax:</b>
	<pre>
	&lt;tbl:headers&gt;
	  ....
      &lt;tbl:columnsubtitles 
        id=...
        clazz=...
        style=...
      /&gt;
   &lt;/tbl:headers&gt;
</pre>

	@author Nicklas
	@since 3.18
*/
public class ColumnSubtitles
	extends StylableTag
{


	private static final long serialVersionUID = -5577600038399464310L;
	private Table table;
	
	public ColumnSubtitles()
	{
		super("headerrow subtitles");
	}

	/*
		Package methods
	*/
	Table getTable()
	{
		return table;
	}

	/*
		Display methods
	*/
	@Override
	public int doStartTag()
		throws JspException
	{
		table = (Table)findAncestorWithClass(this, Table.class);
		try
		{
			if (!table.getColumnSubtitles().isEmpty())
			{
				StringBuilder sb = new StringBuilder();
				sb.append("<tr");
				addIdAndStyles(sb);
				addDynamicAttributes(sb);
				sb.append(">\n");
				int colspan = table.numHeaderColumns()-table.numVisibleColumns();
				if (table.hasStickyHeaders() && colspan > 0)
				{
					sb.append("<th class=\"row-index bg-filled-100\"></th>");
					colspan--;
				}
				if (colspan > 0)
				{
					sb.append("<th colspan=\""+colspan+"\"></th>");
				}
				int numVisibleSubtitles = table.writeColumnSubtitles(sb);
				sb.append("</tr>\n");
				if (numVisibleSubtitles > 0) pageContext.getOut().write(sb.toString());
			}
		}
		catch (Exception ex)
		{
			throw new JspTagException(ex.getMessage());
		}
		return SKIP_BODY;
	}

}

