/*
	$Id: DataCubeExtraValueData.java 6468 2014-06-10 11:27:02Z nicklas $
	
	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg
	
	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/
	
	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.
	
	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

/**
	This class holds information about an extra value in a data cube.
	
	@author Nicklas
	@version 2.0
	@see net.sf.basedb.core.DataCubeExtraValue
	@see <a href="../../../../../../html/developer/api/data_api.experiments.html">Developer documentation: Experiments and analysis</a>
	@base.modified $Date: 2014-06-10 13:27:02 +0200 (Tue, 10 Jun 2014) $
	@hibernate.class table="`DataCubeExtraValues`" lazy="true"
*/
public class DataCubeExtraValueData
	extends BasicData
{
	public DataCubeExtraValueData()
	{}

	private DataCubeData dataCube;
	/**
		Get the data cube this filter belongs to.
		@hibernate.many-to-one column="`datacube_id`" not-null="true" outer-join="false" 
			update="false" unique-key="DataCubeExtraValue_uniqueextra"
	*/
	public DataCubeData getDataCube()
	{
		return dataCube;
	}
	public void setDataCube(DataCubeData dataCube)
	{
		this.dataCube = dataCube;
	}

	private short extraNo;
	/**
		The number of this extra value in the data cube. Must be unique within the data cube.
		@hibernate.property column="`extra_no`" type="short" not-null="true" 
			update="false" unique-key="DataCubeExtraValue_uniqueextra"
	*/
	public short getExtraNo()
	{
		return extraNo;
	}
	public void setExtraNo(short extraNo)
	{
		this.extraNo = extraNo;
	}
	
	private long bytes;
	/**
		The number of bytes the extra values data occupies on disk.
		@hibernate.property column="`bytes`" type="long" not-null="true" update="false"
	*/
	public long getBytes()
	{
		return bytes;
	}
	public void setBytes(long bytes)
	{
		this.bytes = bytes;
	}
	
	private int coordinateType;
	/**
		If the extra value is a spot extra value, a position extra value
		or a column extra value.
		@hibernate.property column="`coordinate_type`" type="int" not-null="true" update="false"
	*/
	public int getCoordinateType()
	{
		return coordinateType;
	}
	public void setCoordinateType(int coordinateType)
	{
		this.coordinateType = coordinateType;
	}

	private int valueType;
	/**
		The type of value, ie. int, float or string.
		@see net.sf.basedb.core.Type
		@hibernate.property column="`value_type`" type="int" not-null="true" update="false"
	*/
	public int getValueType()
	{
		return valueType;
	}
	public void setValueType(int valueType)
	{
		this.valueType = valueType;
	}

}
