/*
	$Id: ItemParameterValueData.java 7075 2016-02-15 10:58:10Z nicklas $

	Copyright (C) 2005 Samuel Andersson, Johan Enell, Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

import java.util.List;
import java.util.ArrayList;

/**
	Item parameter value. The <code>BASE</code> system expect that the values are
	of the type {@link net.sf.basedb.core.BasicItem}. Internally the objects will 
	be converted to {@link BasicData} objects.
	
	@author Nicklas, Samuel
	@version 2.0
	@see <a href="../../../../../../html/developer/api/data_api.parameters.html">Developer documentation: Parameters</a>
	@hibernate.subclass discriminator-value="10"
	@base.modified $Date: 2016-02-15 11:58:10 +0100 (Mon, 15 Feb 2016) $
*/
public class ItemParameterValueData
	extends ParameterValueData<BasicData>
{
	public ItemParameterValueData()
	{}

	public ItemParameterValueData(BasicData... values)
	{
		super(values);
	}

	/**
		@return 0 (No corresponding TYPE entry)
		@since 2.16
	*/
	@Override
	public int getValueType()
	{
		return 0;
	}

	
	private List<BasicData> values;
	/**
		@hibernate.bag table="`ItemValues`" lazy="true"
		@hibernate.collection-key column="`id`"
		@hibernate.many-to-any id-type="int" meta-type=""
		@hibernate.many-to-any-column name="`data_class`" not-null="true" length="255"
		@hibernate.many-to-any-column name="`data_class_id`" not-null="true"
	*/
	@Override
	public List<BasicData> getValues()
	{
		if (values == null)
		{
			values = new ArrayList<BasicData>();
		}
		return values;
	}
	@Override
	void setValues(List<BasicData> values)
	{
		this.values = values;
	}

}
