/*
	$Id: TransformationData.java 7015 2015-11-17 12:57:57Z nicklas $
	
	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg
	
	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/
	
	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.
	
	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

import java.util.Set;
import java.util.HashSet;

/**
	This class holds information about a transformation.
	
	@author Nicklas
	@version 2.0
	@see net.sf.basedb.core.Transformation
	@see <a href="../../../../../../html/developer/api/data_api.experiments.html">Developer documentation: Experiments and analysis</a>
	@base.modified $Date: 2015-11-17 13:57:57 +0100 (Tue, 17 Nov 2015) $
	@hibernate.class table="`Transformations`" lazy="true"
*/
public class TransformationData
	extends BasicData
	implements NameableData, RemovableData
{
	public TransformationData()
	{}

	/*
		From the NameableData interface
		-------------------------------------------
	*/	
	private String name;
	@Override
	public String getName()
	{
		return name;
	}

	@Override
	public void setName(String name)
	{
		this.name = name;
	}

	private String description;
	@Override
	public String getDescription()
	{
		return description;
	}

	@Override
	public void setDescription(String description)
	{
		this.description = description;
	}
	// -------------------------------------------
	/*
		From the RemovableData interface
		-------------------------------------------
	*/
	private Integer removedBy;
	@Override
	public Integer getRemovedBy()
	{
		return removedBy;
	}
	@Override
	public void setRemovedBy(Integer removedBy)
	{
		this.removedBy = removedBy;
	}
	// -------------------------------------------

	private ExperimentData experiment;
	/**
		Get the experiment this bioassayset belongs to.
		@hibernate.many-to-one column="`experiment_id`" not-null="true" outer-join="false" update="false"
	*/
	public ExperimentData getExperiment()
	{
		return experiment;
	}
	public void setExperiment(ExperimentData experiment)
	{
		this.experiment = experiment;
	}

	private BioAssaySetData source;
	/**
		Get the source bioassayset for the transformation. Null if this
		is a root transformation from raw bioassays.
		@hibernate.many-to-one column="`bioassayset_id`" not-null="false" outer-join="false" update="false"
	*/
	public BioAssaySetData getSource()
	{
		return source;
	}
	public void setSource(BioAssaySetData source)
	{
		this.source = source;
	}
	
	private JobData job;
	/**
		Get the job that was used to execute this transformation
		@hibernate.many-to-one column="`job_id`" not-null="false" outer-join="false" update="false"
	*/
	public JobData getJob()
	{
		return job;
	}
	public void setJob(JobData job)
	{
		this.job = job;
	}
	
	private Set<RawBioAssayData> rawSources;
	/**
		Get the source raw bioassays for the transformation.
		@hibernate.set table="`TransformationRawBioAssays`" lazy="true"
		@hibernate.collection-key column="`transformation_id`"
		@hibernate.collection-many-to-many column="`rawbioassay_id`" class="net.sf.basedb.core.data.RawBioAssayData"
	*/
	public Set<RawBioAssayData> getRawSources()
	{
		if (rawSources == null) rawSources = new HashSet<RawBioAssayData>();
		return rawSources;
	}
	void setRawSources(Set<RawBioAssayData> rawSources)
	{
		this.rawSources = rawSources;
	}
	
	private Set<BioAssaySetData> products;
	/**
		This is the inverse end.
		@see BioAssaySetData#getTransformation()
		@hibernate.set lazy="true" inverse="true" cascade="delete"
		@hibernate.collection-key column="`transformation_id`"
		@hibernate.collection-one-to-many class="net.sf.basedb.core.data.BioAssaySetData"
	*/
	Set<BioAssaySetData> getProducts()
	{
		return products;
	}
	void setProducts(Set<BioAssaySetData> products)
	{
		this.products = products;
	}

}
