/**
	$Id: BioMaterialEventLogger.java 6351 2013-11-25 08:20:23Z nicklas $

	Copyright (C) 2009 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.log.db;

import java.util.List;

import net.sf.basedb.core.BioMaterialEvent;
import net.sf.basedb.core.Item;
import net.sf.basedb.core.data.BioMaterialEventData;
import net.sf.basedb.core.data.ChangeHistoryDetailData;
import net.sf.basedb.core.log.EntityDetails;
import net.sf.basedb.core.log.ChangeType;
import net.sf.basedb.core.log.EntityLogger;
import net.sf.basedb.core.log.LogManager;

/**
	Logger for biomaterial events that logs UPDATE:s to 
	CREATION and HYBRIDIZATION events as updates to their
	parent biomaterial/hybridization. OTHER events are not 
	logged.

	@author Nicklas
	@version 2.13
	@base.modified $Date: 2013-11-25 09:20:23 +0100 (Mon, 25 Nov 2013) $
*/
public class BioMaterialEventLogger
	implements EntityLogger
{

	private final DbLogManagerFactory factory;
	private final boolean detailedProperties;
	private final boolean oldPropertyValues;

	/**
		Creates a new biomaterial event logger.
		@param factory The log manager factory
	*/
	public BioMaterialEventLogger(DbLogManagerFactory factory)
	{
		this.factory = factory;
		this.detailedProperties = factory.isLoggingDetailedProperties();
		this.oldPropertyValues = factory.isLoggingOldPropertyValues();
	}
	
	/*
		From the EntityLogger interface
		-------------------------------
	*/
	@Override
	public void logChanges(LogManager logManager, EntityDetails details)
	{
		// We are only logging update events. CREATE and DELETE events are
		// usually also catched by other loggers
		if (details.getChangeType() != ChangeType.UPDATE) return;
		
		BioMaterialEventData event = (BioMaterialEventData)details.getEntity();
		BioMaterialEvent.Type eventType = BioMaterialEvent.Type.fromValue(event.getEventType());
		
		List<ChangeHistoryDetailData> changes = null;
		if (eventType == BioMaterialEvent.Type.CREATION)
		{
			changes = details.toChangeDetails(Item.fromDataObject(event.getBioMaterial()), event.getBioMaterial().getId(), 
				"creationEvent", ChangeType.UPDATE, detailedProperties, oldPropertyValues);
		}
		else if (eventType == BioMaterialEvent.Type.BIOASSAY)
		{
			changes = details.toChangeDetails(Item.PHYSICALBIOASSAY, event.getPhysicalBioAssay().getId(), 
				"creationEvent", ChangeType.UPDATE, detailedProperties, oldPropertyValues);
		}
		
		DbLogManager dbLogManager = (DbLogManager)logManager;
		dbLogManager.logChangeDetails(changes, details);
	}
	// -------------------------------
}
