/**
	$Id$

	Copyright (C) 2011 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.migrate;

import java.io.IOException;
import java.io.Writer;
import java.sql.ResultSet;
import java.sql.SQLException;



/**
	Generic writer implementation that writes byte-array values 
	from a result set. An escape map should be given at construction
	time that maps byte-values (0-255) to an escape char[] sequence.
	If no escape sequence is given the original byte is written
	as is using {@link Writer#write(int)}. This writer use 
	{@link ResultSet#getBytes(int)} to read data from the result set.
	
	@author Nicklas
	@since 3.1
	@base.modified $Date$
*/
public class ByteArrayWriter
	extends AbstractResultWriter
{
	
	private final char[][] ESCAPE;
	
	public ByteArrayWriter(ResultSet rs, int index, Writer writer, 
		char[] nullEscape, char[][] byteEscape)
	{
		super(rs, index, writer, nullEscape);
		this.ESCAPE = byteEscape;
	}

	@Override
	public void write()
		throws SQLException, IOException
	{
		byte[] bytes = rs.getBytes(index);
		if (bytes == null)
		{
			writer.write(NULL_ESCAPE);
		}
		else
		{
			for (int i = 0; i < bytes.length; ++i)
			{
				int b = bytes[i] & 0xff;
				char[] escape = ESCAPE[b];
				if (escape != null)
				{
					writer.write(escape);
				}
				else
				{
					writer.write(b);
				}
			}
		}
	}
	
}
