/**
	$Id$

	Copyright (C) 2011 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.migrate;

import java.io.IOException;
import java.io.Writer;
import java.sql.ResultSet;
import java.sql.SQLException;


/**
	Database-independent writer implementation that writes short 
	values from a result set. This writer use 
	{@link ResultSet#getShort(int)} to read data from the result set
	and {@link Short#toString(short)} to format the value.
	
	@author Nicklas
	@since 3.1
	@base.modified $Date: 2011-11-30 11:58:08 +0100 (on, 30 nov 2011) $
*/
public class ShortWriter
	extends AbstractResultWriter
{
	
	public ShortWriter(ResultSet rs, int index, Writer writer, char[] nullEscape)
	{
		super(rs, index, writer, nullEscape);
	}

	@Override
	public void write() 
		throws SQLException, IOException
	{
		short value = rs.getShort(index);
		if (rs.wasNull())
		{
			writer.write(NULL_ESCAPE);
		}
		else
		{
			writer.write(Short.toString(value));
		}
	}
	
}
