/**
	$Id$

	Copyright (C) 2015 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.listable;

import java.util.HashSet;
import java.util.Set;

import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.DerivedBioAssay;
import net.sf.basedb.core.Item;
import net.sf.basedb.core.ItemQuery;
import net.sf.basedb.core.query.Expressions;
import net.sf.basedb.core.query.Hql;
import net.sf.basedb.core.query.Restrictions;

/**
	Source item transformer implementation that transform derived bioassay items 
	to child derived bioassays.
	
	@author Nicklas
	@since 3.5
*/
public class DerivedBioAssayToChildDerivedBioAssayTransformer 
	extends AbstractSourceItemTransformer
{
	
	private final boolean includeSourcesInTarget;

	/**
		Create a new derived bioassay to child derived bioassay transformer.
	*/
	public DerivedBioAssayToChildDerivedBioAssayTransformer(boolean includeSourcesInTarget) 
	{
		super(Item.DERIVEDBIOASSAY, Item.DERIVEDBIOASSAY);
		this.includeSourcesInTarget = includeSourcesInTarget;
	}
	
	@Override
	public Set<Integer> transform(TransformContext context, Set<Integer> source) 
	{
		DbControl dc = context.getDbControl();
		
		ItemQuery<DerivedBioAssay> query = DerivedBioAssay.getQuery();
		query.setIncludes(context.getInclude());
		query.joinPermanent(Hql.innerJoin("parents", "p"));
		query.restrictPermanent(
			Restrictions.in(
				Hql.alias("p"),
				Expressions.parameter("parents")
			)
		);
		
		// Keep track of all seen children and parents
		Set<Integer> allParents = new HashSet<Integer>();
		Set<Integer> allChildren = new HashSet<Integer>();
		if (includeSourcesInTarget) allChildren.addAll(source);

		// Parents that we have not yet checked
		Set<Integer> parents = source;
		while (parents.size() > 0)
		{
			context.collect(getSourceItemType(), parents);
			Set<Integer> children = context.avoid(getTargetItemType(), safeIdList(dc, query, "parents", parents));
			
			// Store new children and "used" parents
			allChildren.addAll(children);
			allParents.addAll(parents);
			
			// Remove parents that we have already seen...
			// ...the remaining children become our new parents
			children.removeAll(allParents);
			parents = children;
		}
		
		return allChildren;
	}

}
