/**
	$Id$

	Copyright (C) 2020 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.overview.loader;

import net.sf.basedb.core.BasicItem;
import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.File;
import net.sf.basedb.core.Item;
import net.sf.basedb.core.PermissionDeniedException;
import net.sf.basedb.core.Protocol;
import net.sf.basedb.util.overview.Node;
import net.sf.basedb.util.overview.OverviewContext;
import net.sf.basedb.util.overview.node.ChildNodeDirection;
import net.sf.basedb.util.overview.node.NameableNameGenerator;
import net.sf.basedb.util.overview.node.NodeFactory;

/**
	Node loader implementation for files. Files must be loaded as
	property nodes. It can't be a root node or a forward/reverse-loading 
	node. The property node itself is created as a property-loading node
	that loads the annotations when asked to load it's children.
	
	@author Nicklas
	@since 3.17
*/
public class FileLoader
	extends BasicItemNodeLoader<File>
{

	public FileLoader()
	{
		super(Item.FILE, DENY_ROOT_NODE, 
				new NameableNameGenerator<File>("file", "File"));
	}
	
	/*
		From the NodeLoader interface
		------------------------------
	*/
	@Override
	public Node createPropertyNode(DbControl dc, OverviewContext context, Node parentNode)
	{
		File file = null;
		boolean denied = false;
		try
		{
			BasicItem parentItem = parentNode.getItem(dc);
			if (parentItem instanceof Protocol)
			{
				file = ((Protocol)parentItem).getFile();
			}
			// If there are more items that link to files we should add them here
		}
		catch (PermissionDeniedException ex)
		{
			denied = true;
		}
		
		NodeFactory<File> nf = getNodeFactory(dc, context);
		Node fileNode = createItemNode(nf, file, file, denied, 
				parentNode, ChildNodeDirection.PROPERTY);
		return fileNode;
	}
	// -----------------------------------
	/*
		From the AbstractNodeLoader class
		----------------------------------
	*/
	/**
		Loads annotations for the given file node.
		@see RawBioAssayLoader#createForwardNode(DbControl, OverviewContext, Node)
	*/
	@Override
	protected void loadPropertyChildNodes(DbControl dc, OverviewContext context, Node fileNode)
	{
		getNodeLoader(context, Item.ANNOTATION).createPropertyNode(dc, context, fileNode);
	}
	// -------------------------------------
}