<%-- $Id: index.jsp 7954 2021-05-12 13:27:22Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg, Martin Svensson

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
	@version 2.0
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.Item"
	import="net.sf.basedb.core.Include"
	import="net.sf.basedb.core.PluginType"
	import="net.sf.basedb.core.ItemQuery"
	import="net.sf.basedb.core.Permission"
	import="net.sf.basedb.core.ItemContext"
	import="net.sf.basedb.core.MultiPermissions"
	import="net.sf.basedb.core.PermissionDeniedException"
	import="net.sf.basedb.core.PluginDefinition"
	import="net.sf.basedb.core.ItemAlreadyExistsException"
	import="net.sf.basedb.core.query.Expressions"
	import="net.sf.basedb.core.query.Hql"
	import="net.sf.basedb.core.query.Orders"
	import="net.sf.basedb.core.query.Restrictions"
	import="net.sf.basedb.util.RemovableUtil"
	import="net.sf.basedb.util.formatter.NameableFormatter"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.WebException"
	import="net.sf.basedb.util.Values"
	import="net.sf.basedb.clients.web.plugins.ItemQueryLoader"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.core.plugin.GuiContext"
	import="net.sf.basedb.util.extensions.ExtensionsInvoker"
	import="net.sf.basedb.clients.web.extensions.ExtensionsControl"
	import="net.sf.basedb.clients.web.extensions.JspContext"
	import="net.sf.basedb.clients.web.extensions.edit.EditUtil"
	import="net.sf.basedb.clients.web.extensions.edit.OnSaveAction"
	import="net.sf.basedb.clients.web.extensions.edit.OnSaveRenderer"
	import="net.sf.basedb.clients.web.extensions.list.ListColumnExportRenderer"
	import="net.sf.basedb.clients.web.extensions.list.ListColumnAction"
	import="net.sf.basedb.clients.web.extensions.list.ListColumnUtil"
	import="java.util.Enumeration"
	import="java.util.Set"
	import="java.util.HashSet"
	import="java.util.List"
	import="java.util.ArrayList"
	import="java.util.Collections"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%!
	private static final ItemContext defaultContext = Base.createDefaultContext("name", "name,interfaceName,description");
	private static final Item itemType = Item.PLUGINTYPE;
	
	private static void registerExportUtils(ItemContext cc)
	{
		// Register formatters
		cc.setObject("export.formatter.&plugins(name)", new NameableFormatter());
		
		// Register dataloaders
		String typeParameter = "pluginType";
		ItemQuery<PluginDefinition> pluginQuery = PluginDefinition.getQuery();
		pluginQuery.include(cc.getInclude());
		pluginQuery.include(Include.MINE, Include.SHARED, Include.IN_PROJECT, Include.OTHERS);
		pluginQuery.join(Hql.innerJoin("pluginTypes", "pt"));
		pluginQuery.restrict(Restrictions.eq(Hql.alias("pt"), Expressions.parameter(typeParameter)));
		pluginQuery.order(Orders.asc(Hql.property("name"))); 
		cc.setObject("export.dataloader.&plugins(name)", new ItemQueryLoader<PluginType>(pluginQuery, typeParameter));
	}
%>
<%
final SessionControl sc = Base.getExistingSessionControl(pageContext, true);
final String ID = sc.getId();
final String cmd = request.getParameter("cmd");
final String root = request.getContextPath()+"/";
final String mode = request.getParameter("mode");
final String callback = request.getParameter("callback");
final String itemId = request.getParameter("item_id");
final String listPage = "list_plugintypes.jsp?ID="+ID
	+(mode == null ? "" : "&mode="+mode)
	+(callback == null ? "" : "&callback="+callback)
	+(itemId == null ? "" : "&item_id="+itemId);
final String viewPage = "view_plugintype.jsp?ID="+ID;
final String editPage = "edit_plugintype.jsp?ID="+ID;

String forward = null;
String redirect = null;
String message = null;
DbControl dc = null;

try
{
	if (cmd == null || "List".equals(cmd))
	{
		// Display the list page without updatinging the current context
		Base.getAndSetCurrentContext(sc, itemType, null, defaultContext, true);
		redirect = listPage;
	}
	else if ("UpdateContext".equals(cmd))
	{
		// Display the list page after updating the current context from the request parameters
		Base.getAndSetCurrentContext(sc, itemType, pageContext, defaultContext);
		redirect = listPage;
	}
	else if ("LoadContext".equals(cmd))
	{
		// Display the list page after loading a saved context
		int contextId = Values.getInt(request.getParameter("context"));
		Base.loadContext(sc, contextId, defaultContext);
		redirect = listPage;
	}

	else if ("ViewItem".equals(cmd))
	{
		// Display the view page for a single item 
		ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, pageContext, defaultContext);
		forward = viewPage;
	}
	else if ("EditItem".equals(cmd))
	{
		// Display the edit page for a single item (should be opened in a popup)
		ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, pageContext, defaultContext);
		redirect = editPage;
	}
	else if ("NewItem".equals(cmd))
	{
		// Display the edit page for a new item (should be opened in a popup)
		if (!sc.hasPermission(Permission.CREATE, itemType))
		{
			throw new PermissionDeniedException(Permission.CREATE, itemType.toString());
		}
		ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, pageContext, defaultContext);
		cc.setId(0);
		redirect = editPage;
	}
	else if ("UpdateItem".equals(cmd))
	{
		// Update the properties on an item (will close the popup)
		ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, null, defaultContext);
		dc = sc.newDbControl(":Edit "+itemType);
		PluginType pluginType = cc.getObject("item");
		String interfaceName = Values.getStringOrNull(request.getParameter("interfaceName"));
		String jarFile = Values.getStringOrNull(request.getParameter("jarFile"));
		if (pluginType == null)
		{
			pluginType = PluginType.getNew(dc, interfaceName, jarFile);
			message = "Plugin type created";
			dc.saveItem(pluginType);
		}
		else
		{
			dc.reattachItem(pluginType, false);
			pluginType.loadInterfaceInformation(jarFile, interfaceName);
			message = "Plugin type updated";
		}
		JspContext jspContext = ExtensionsControl.createContext(dc, pageContext, GuiContext.item(Item.PLUGINTYPE), pluginType);
		ExtensionsInvoker<OnSaveAction> invoker = EditUtil.useOnSaveExtensions(jspContext);
		try
		{
			pluginType.setName(Values.getStringOrNull(request.getParameter("name")));
			pluginType.setDescription(Values.getStringOrNull(request.getParameter("description")));
			
			// OnSave extensions
			invoker.render(OnSaveRenderer.ON_SAVE);
			dc.commit();
			invoker.render(OnSaveRenderer.ON_COMMIT);
		}
		catch (Exception ex)
		{
			invoker.render(OnSaveRenderer.onRollback(ex));
			throw ex;
		}
		finally
		{
			cc.removeObject("item");
		}
	}
	else if ("DeleteItem".equals(cmd))
	{
		// Delete a single item and then return to the view page
		dc = sc.newDbControl(":Delete "+itemType);
		ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, pageContext, defaultContext);
		RemovableUtil.setRemoved(dc, itemType, Collections.singleton(cc.getId()), true);
		dc.commit();
		redirect = viewPage;
	}
	else if ("DeleteItems".equals(cmd))
	{
		// Delete all selected items on the list page
		dc = sc.newDbControl(":Delete "+itemType);
		ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, pageContext, defaultContext);
		int numTotal = cc.getSelected().size();
		int numRemoved = RemovableUtil.setRemoved(dc, itemType, cc.getSelected(), true);
		dc.commit();
		if (numTotal != numRemoved)
		{
			message = (numRemoved == 0 ? "No" : "Only "+numRemoved+" of "+numTotal) + " items could be deleted, because you have no DELETE permission";
		}
		redirect = listPage;
	}
	else if ("RestoreItem".equals(cmd))
	{
		// Restore a single item and then return to the view page
		dc = sc.newDbControl(":Restore "+itemType);
		ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, pageContext, defaultContext);
		RemovableUtil.setRemoved(dc, itemType, Collections.singleton(cc.getId()), false);
		dc.commit();
		redirect = viewPage;
	}
	else if ("RestoreItems".equals(cmd))
	{
		// Restore all selected items on the list page
		dc = sc.newDbControl(":Restore "+itemType);
		ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, pageContext, defaultContext);
		int numTotal = cc.getSelected().size();
		int numRemoved = RemovableUtil.setRemoved(dc, itemType, cc.getSelected(), false);
		dc.commit();
		if (numTotal != numRemoved)
		{
			message = (numRemoved == 0 ? "No" : "Only "+numRemoved+" of "+numTotal) + " items could be restored, because you have no WRITE permission";
		}
		redirect = listPage;
	}
	else if ("ExportItems".equals(cmd))
	{
		// Run an export plugin in a list context
		ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, pageContext, defaultContext);
		final ItemQuery<PluginType> query = PluginType.getQuery();
		dc = sc.newDbControl(":Export "+itemType);
		JspContext jspContext = ExtensionsControl.createContext(dc, pageContext, GuiContext.list(itemType), null);
		cc.configureQuery(dc, query, jspContext, true);
		cc.setQuery(query);
		registerExportUtils(cc);
		ExtensionsInvoker<ListColumnAction<PluginType,?>> listInvoker = ListColumnUtil.useExtensions(jspContext);
		listInvoker.render(new ListColumnExportRenderer<PluginType>(cc));
		dc.close();
		redirect = "../../common/export/index.jsp?ID="+ID+"&cmd=SelectPlugin&item_type="+itemType.name()+"&context_type=LIST&title=Export+plugin+types";
	}
	else if ("ExportItem".equals(cmd))
	{
		// Run an export plugin in single-item context
		ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, pageContext, defaultContext);
		registerExportUtils(cc);
		redirect = "../../common/export/index.jsp?ID="+ID+"&cmd=SelectPlugin&item_type="+itemType.name()+"&context_type=ITEM&title=Export+plugin+type";
	}
	else if ("ImportItems".equals(cmd))
	{
		// Run an import plugin in a list context
		ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, pageContext, defaultContext);
		final ItemQuery<PluginType> query = PluginType.getQuery();
		dc = sc.newDbControl(":Import "+itemType);
		JspContext jspContext = ExtensionsControl.createContext(dc, pageContext, GuiContext.list(itemType), null);
		cc.configureQuery(dc, query, jspContext, true);
		dc.close();
		cc.setQuery(query);
		redirect = "../../common/import/index.jsp?ID="+ID+"&cmd=SelectPlugin&item_type="+itemType.name()+"&context_type=LIST&title=Import+plugin+types";
	}
	else if ("ImportItem".equals(cmd))
	{
		// Run an import plugin in single-item context
		ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, pageContext, defaultContext);
		redirect = "../../common/import/index.jsp?ID="+ID+"&cmd=SelectPlugin&item_type="+itemType.name()+"&context_type=ITEM&title=Import+plugin+type";
	}
	else if ("RunListPlugin".equals(cmd))
	{
		// Run another plugin in a list context
		ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, pageContext, defaultContext);
		final ItemQuery<PluginType> query = PluginType.getQuery();
		dc = sc.newDbControl(":Run plugin "+itemType);
		JspContext jspContext = ExtensionsControl.createContext(dc, pageContext, GuiContext.list(itemType), null);
		cc.configureQuery(dc, query, jspContext, true);
		dc.close();
		cc.setQuery(query);
		redirect = "../../common/plugin/index.jsp?ID="+ID+"&cmd=SelectPlugin&item_type="+itemType.name()+"&context_type=LIST&main_type=OTHER&title=Run+plugin";
	}
	else if ("RunPlugin".equals(cmd))
	{
		// Run another plugin in single-item context
		ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, pageContext, defaultContext);
		redirect = "../../common/plugin/index.jsp?ID="+ID+"&cmd=SelectPlugin&item_type="+itemType.name()+"&context_type=ITEM&main_type=OTHER&title=Run+plugin";
	}
	else
	{
		throw new WebException("popup", "Invalid command", "The command {1} is not recognised as a valid command.", cmd);
	}
}
finally
{
	if (dc != null) dc.close();
}

if (forward != null)
{
	sc.setSessionSetting("alert-message", message);
	pageContext.forward(forward);
}
else if (redirect != null)
{
	sc.setSessionSetting("alert-message", message);
	response.sendRedirect(redirect);
}
else if (message == null)
{
	response.sendRedirect(root + "common/close_popup.jsp?refresh_opener=1&wait=0");
}
else
{
	response.sendRedirect(root + "common/close_popup.jsp?refresh_opener=1&message="+HTML.urlEncode(message));
}
%>

