<%-- $Id: view_unit.jsp 7954 2021-05-12 13:27:22Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg, Martin Svensson

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
	@version 2.0
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.SystemItems"
	import="net.sf.basedb.core.Item"
	import="net.sf.basedb.core.ItemContext"
	import="net.sf.basedb.core.Permission"
	import="net.sf.basedb.core.Quantity"
	import="net.sf.basedb.core.Unit"
	import="net.sf.basedb.core.PermissionDeniedException"
	import="net.sf.basedb.core.PluginDefinition"
	import="net.sf.basedb.core.data.RawData"
	import="net.sf.basedb.core.plugin.GuiContext"
	import="net.sf.basedb.core.plugin.Plugin"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.PermissionUtil"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.util.Values"
	import="net.sf.basedb.clients.web.extensions.ExtensionsControl"
	import="net.sf.basedb.clients.web.extensions.JspContext"
	import="net.sf.basedb.clients.web.extensions.renderer.PrefixSuffixRenderer"
	import="net.sf.basedb.clients.web.extensions.toolbar.ButtonAction" 
	import="net.sf.basedb.clients.web.extensions.toolbar.ToolbarUtil"
	import="net.sf.basedb.util.extensions.ExtensionsInvoker"
	import="java.util.Date"
	import="java.util.Map"
	import="java.util.Set"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%@ taglib prefix="t" uri="/WEB-INF/tab.tld" %>
<%@ taglib prefix="tbl" uri="/WEB-INF/table.tld" %>
<%@ taglib prefix="p" uri="/WEB-INF/path.tld" %>
<%@ taglib prefix="ext" uri="/WEB-INF/extensions.tld" %>
<%!
	private static final Item itemType = Item.UNIT;
	private static final GuiContext guiContext = new GuiContext(itemType, GuiContext.Type.ITEM);
%>
<%
final SessionControl sc = Base.getExistingSessionControl(pageContext, true);
final String ID = sc.getId();
final ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, null, null);
final int itemId = cc.getId();
final String tab = Values.getStringOrNull(request.getParameter("tab"));
final float scale = Base.getScale(sc);
final DbControl dc = sc.newDbControl(":View "+itemType);
try
{
	Map<Plugin.MainType, Integer> pluginCount = PluginDefinition.countPlugins(dc, guiContext);

	String title = null;
	final Unit unit = Unit.getById(dc, itemId);
	final Quantity quantity = unit.getQuantity();
	final int quantityId = quantity.getId();

	Set<String> symbols = unit.getSymbols();
	symbols.remove(unit.getDisplaySymbol());
	symbols.add("<b>" + unit.getDisplaySymbol() + "</b>");
	
	StringBuilder formula = new StringBuilder();
	formula.append("1").append(unit.getDisplaySymbol()).append(" = ");
	if (unit.getReferenceFactor() != 1.0)
	{
		formula.append(unit.getReferenceFactor()).append(" × ");
	}
	formula.append(quantity.getReferenceUnit());
	if (unit.getReferenceOffset() != 0.0)
	{
		formula.append(" + ").append(unit.getReferenceOffset());
	}
	
	final boolean writePermission = unit.hasPermission(Permission.WRITE);
	final boolean deletePermission = unit.hasPermission(Permission.DELETE);
	final boolean isRemoved = unit.isRemoved();
	final boolean isUsed = isRemoved && unit.isUsed();
	final boolean deletePermanentlyPermission = deletePermission && !isUsed;
	JspContext jspContext = ExtensionsControl.createContext(dc, pageContext, guiContext, unit);
	ExtensionsInvoker<ButtonAction> invoker = ToolbarUtil.useExtensions(jspContext);
	%>
	<base:page title="<%=title%>" id="view-page">
	<base:head scripts="table.js,tabcontrol-2.js,~units.js" styles="toolbar.css,table.css,headertabcontrol.css,path.css">
		<ext:scripts context="<%=jspContext%>" />
		<ext:stylesheets context="<%=jspContext%>" />
	</base:head>
	<base:body>
		<p:path><p:pathelement 
			title="Quantities" href="<%="../index.jsp?ID="+ID%>" 
			/><p:pathelement 
				title="<%=HTML.encodeTags(quantity.getName())%>" 
				href="<%="index.jsp?ID="+ID+"&amp;quantity_id="+quantityId%>"
			/><p:pathelement title="<%=HTML.encodeTags(unit.getName())%>" 
			/></p:path>
		<div id="page-data" data-item-id="<%=itemId%>" data-quantity-id="<%=quantityId%>"></div>
		
		<t:tabcontrol 
			id="main" 
			subclass="content mastertabcontrol" 
			active="<%=tab%>">
		<t:tab id="properties" title="Properties">
			<div>
			<table class="fullform bottomborder">
			<tr>
				<th class="itemstatus">
					<base:icon 
						id="btnDeletePermanently"
						image="deleted.png"
						tooltip="This item has been flagged for deletion. Click to delete it now."
						enabled="<%=deletePermanentlyPermission %>"
						visible="<%=isRemoved%>" 
					/>
					<base:icon 
						id="btnUsingItems"
						image="used.png" 
						tooltip="This item is used by other items and can't be permanently deleted. Show the items that are using this one"
						visible="<%=isRemoved && isUsed%>" />
				</th>
				<td style="padding: 0px;">
					<tbl:toolbar subclass="bottomborder bg-filled-50">
						<tbl:button 
							id="btnEdit"
							disabled="<%=!writePermission%>" 
							image="edit.png" 
							title="Edit&hellip;" 
							tooltip="<%=writePermission ? "Edit this unit" : "You do not have permission to edit this unit"%>" 
						/>
						<tbl:button 
							id="btnDelete"
							disabled="<%=!deletePermission%>" 
							image="delete.png" 
							title="Delete"
							visible="<%=!isRemoved%>"
							tooltip="<%=deletePermission ? "Delete this unit" : "You do not have permission to delete this unit"%>" 
						/>
						<tbl:button 
							id="btnRestore"
							disabled="<%=!writePermission%>" 
							image="restore.png" 
							title="Restore"
							visible="<%=isRemoved%>"
							tooltip="<%=writePermission ? "Restore this unit" : "You do not have permission to restore this unit"%>" 
						/>
						<tbl:button 
							id="btnImport"
							image="import.png" 
							data-plugin-type="IMPORT"
							title="Import&hellip;" 
							tooltip="Import data" 
							visible="<%=pluginCount.containsKey(Plugin.MainType.IMPORT)%>"
						/>
						<tbl:button 
							id="btnExport"
							image="export.png"
							data-plugin-type="EXPORT"
							title="Export&hellip;" 
							tooltip="Export data" 
							visible="<%=pluginCount.containsKey(Plugin.MainType.EXPORT)%>"
						/>
						<tbl:button 
							id="btnRunPlugin"
							image="runplugin.png"  
							data-plugin-type="OTHER" 
							title="Run plugin&hellip;" 
							tooltip="Run a plugin" 
							visible="<%=pluginCount.containsKey(Plugin.MainType.OTHER)%>"
						/>
						<ext:render extensions="<%=invoker%>" context="<%=jspContext%>" 
							wrapper="<%=new PrefixSuffixRenderer<ButtonAction>(jspContext, "<td>", "</td>") %>"/>
						<tbl:button
							image="help.png"
							subclass="auto-init"
							data-auto-init="help"
							data-help-id="unit.view.properties"
							title="Help&hellip;"
							tooltip="Get help about this page"
						/>
					</tbl:toolbar>
				</td>
			</tr>
			<tr>
				<tH>Name</tH>
				<td><%=HTML.encodeTags(unit.getName())%></td>
			</tr>
			<tr>
				<tH>Symbols</tH>
				<td><%=Values.getString(symbols, ", ", true)%></td>
			</tr>
			<tr>
				<tH>Conversion formula</tH>
				<td><%=HTML.encodeTags(formula.toString())%></td>
			</tr>
			<tr>
				<th>Permissions</th>
				<td><%=PermissionUtil.getFullPermissionNames(unit)%></td>
			</tr>
			<tr >
				<tH>Description</tH>
				<td><%=HTML.formatLineBreaks(HTML.encodeTags(unit.getDescription()))%></td>
			</tr>
			</table>
			</div>
			<jsp:include page="../../../common/anytoany/list_anytoany.jsp">
				<jsp:param name="ID" value="<%=ID%>" />
				<jsp:param name="item_type" value="<%=itemType.name()%>" />
				<jsp:param name="item_id" value="<%=itemId%>" />
				<jsp:param name="title" value="Other items related to this unit" />
			</jsp:include>
		</t:tab>
		</t:tabcontrol>

	</base:body>
	</base:page>
	<%
}
finally
{
	if (dc != null) dc.close();
}

%>
