/* $Id $
	------------------------------------------------------------------
	Copyright (C) 2013 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
*/
'use strict';

var Trashcan = function()
{
	var trashcan = {};
	
	/**
		Initialize the page.
	*/
	trashcan.initPage = function()
	{
		var pageId = Doc.getPageId();
		if (pageId == 'view-page')
		{
			var itemType = Data.get('page-data', 'item-type');
			var itemId = Data.get('page-data', 'item-id');
			var attributes = {'item-type': itemType, 'item-id': itemId};
			var tableAttributes = {'table-id': 'usingItems', 'regexp': 'item:'};
			
			Buttons.addClickHandler('btnEdit', Buttons.editItem, attributes);
			Buttons.addClickHandler('btnDeleteItem', trashcan.deleteItem, attributes);
			Buttons.addClickHandler('btnRestore', Buttons.restoreItem, attributes);
			Buttons.addClickHandler('btnShare', Buttons.shareItem, attributes);

			Buttons.addClickHandler('btnDeleteItems', Buttons.deleteItems, tableAttributes);
			Buttons.addClickHandler('btnRestoreItems', Buttons.restoreItems, tableAttributes);

		}
		else if (pageId == 'list-page')
		{
			var tableAttributes = {'table-id': 'trashcan', 'regexp': 'item:'};
			
			Buttons.addClickHandler('btnDeleteAllItems', trashcan.deleteAllItems);
			Buttons.addClickHandler('btnDeleteItems', trashcan.deleteSelectedItems);
			Buttons.addClickHandler('btnRestoreItems', Buttons.restoreItems, tableAttributes);
			
			Buttons.addClickHandler('btnColumns', Buttons.configureColumns, tableAttributes);
		}
	}
	
	trashcan.initElements = function(element, autoInit)
	{
		if (autoInit == 'show-using-items')
		{
			Buttons.addClickHandler(element, trashcan.showUsingItems);
		}
	}

	trashcan.deleteAllItems = function()
	{
		if (!confirm('You are about to PERMANENTLY DELETE all items.\n This can\'t be undone. Continue?'))
		{
			return;
		}
		var url = '../../common/progress_reporter.jsp?ID='+App.getSessionId();
		url += '&progress=trashcan&title=Empty trashcan';
		Dialogs.openPopup(url, 'EmptyTrashProgress', 400, 200);
		var frm = document.forms['trashcan'];
		frm.cmd.value = 'DeleteAllPermanently';
		frm.submit();
	}
	
	trashcan.deleteSelectedItems = function()
	{
		var frm = document.forms['trashcan'];
		var numChecked = Table.checkIfSelected('trashcan', /item:/);
		if (numChecked == 0) return;

		var items = numChecked == 1 ? 'item' : 'items';
		if (!confirm('You are about to PERMANENTLY DELETE '+numChecked+' '+items+'.\n This can\'t be undone. Continue?'))
		{
			return;
		}
		var url = '../../common/progress_reporter.jsp?ID='+App.getSessionId();
		url += '&progress=trashcan&title=Delete items';
		Dialogs.openPopup(url, 'EmptyTrashProgress', 400, 200);
		frm.cmd.value = 'DeleteItemsPermanently';
		frm.submit();
	}

	trashcan.showUsingItems = function(event)
	{
		var url = 'index.jsp?ID='+App.getSessionId();
		url += '&cmd=ViewUsingItems&item_type='+Data.get(event.currentTarget, 'item-type');
		url += '&item_id='+Data.get(event.currentTarget, 'item-id');
		location.href = url;
	}
	
	trashcan.deleteItem = function(event)
	{
		if (!confirm('You are about to PERMANENTLY DELETE this item.\n This can\'t be undone. Continue?'))
		{
			return;
		}
		var url = 'index.jsp?ID='+App.getSessionId();
		url += '&cmd=DeleteItem&item_type='+Data.get(event.currentTarget, 'item-type');
		url += '&item_id='+Data.get(event.currentTarget, 'item-id');
		location.replace(url);
	}
	
	return trashcan;
}();

Doc.onLoad(Trashcan.initPage);
Doc.addElementInitializer(Trashcan.initElements);
